On Thu, 03 Jul 2014 21:18:32 +0200, Mark Kettenis wrote:

>> From: Ralph Siegler <rsieg...@rsiegler.org>
>> Date: Wed, 2 Jul 2014 00:39:37 +0000 (UTC)
>> 
>> The display on this emac goes blank right at the end of booting, even
>> though display works fine from bsd.rd
>> 
>> 
>> Not using X and answered "No" to expecting to use X during install.
>> 
>> Now emac with radeon is not in the list of supported machines, however
>> since things do work from bsd.rd I was wondering if there was any
>> setting I could "knock out" to just get basic console?
> 
> disabling radeondrm should work; see config(8) for details
> 
> I've just committed the diff below, which might help (but probably
> doesn't).  More likely some changes are necessary in radeon_combios.c,
> in particular in radeon_get_legacy_connector_info_from_table().  As you
> can see, your model (PowerMac6,4) isn't listed there.  It might be worth
> trying to map your "PowerMac6,4" to CT_MINI_INTERNAL or CT_MINI_EXTERNAL
> in that function and see if that makes things work.
> 


brought machine up to -current, and made kernel with diff below but still 
goes black at end of boot   (startx with "radeon" in xorg.conf driver 
doesn't work either)

I'll try some other table settings



$ diff -u /home/ziggy/radeon/radeon_combios.c \     
>  /usr/src/sys/dev/pci/drm/radeon/radeon_combios.c 
--- /home/ziggy/radeon/radeon_combios.c Mon Apr  7 07:58:44 2014
+++ /usr/src/sys/dev/pci/drm/radeon/radeon_combios.c    Thu Jul  3 
21:46:38 2014
@@ -1503,8 +1503,9 @@
                } else if (of_machine_is_compatible("PowerMac4,4")) {
                        /* emac */
                        rdev->mode_info.connector_table = CT_EMAC;
-               } else if (of_machine_is_compatible("PowerMac10,1")) {
-                       /* mini with internal tmds */
+               } else if (of_machine_is_compatible("PowerMac10,1") ||
+                          of_machine_is_compatible("PowerMac6,4")) {
+                       /* mini with internal tmds, or PowerMac6,4 */
                        rdev->mode_info.connector_table = 
CT_MINI_INTERNAL;
                } else if (of_machine_is_compatible("PowerMac10,2")) {
                        /* mini with external tmds */






$ eeprom 
name=options
little-endian?=false
real-mode?=false
auto-boot?=true
diag-switch?=false
fcode-debug?=false
oem-banner?=false
oem-logo?=false
use-nvramrc?=false
use-generic?=false
default-mac-address?=false
scroll-lock=true
skip-netboot?=false
real-base=-1
real-size=-1
load-base=0x800000
virt-base=-1
virt-size=-1
logger-base=-1
logger-size=0
pci-probe-mask=-1
screen-#columns=100
screen-#rows=40
selftest-#megs=0
boot-volume=3
boot-device=hd:,ofwboot /bsd
boot-file=
boot-screen=screen
console-screen=screen
diag-device=enet
diag-file=,diags
input-device=keyboard
output-device=screen
input-device-1=scca
output-device-1=scca
mouse-device=mouse
oem-banner=
eeprom: property `oem-logo' not yet supported
nvramrc=
boot-command=mac-boot
default-client-ip=
default-server-ip=
default-gateway-ip=
default-subnet-mask=
default-router-ip=
boot-script=
aapl,pci=/@f0000000/@10\377\001R2AD\377\001\004>\202\377\201\001\007\027
\377\201\001\315\004\034\202\377\201\001\007\027\377\201\001V&\277\004\377
\201\001\005`\377\201\0010\377\201\001`\003\377\201\001\003*\377\201\001
\001\377\201\001\003\003\377\201\001\004\377\201\002\003\036\303\004\377
\201\001\005 \377\201\001\020\377\201\001`\003\377\201\001\003 \377\201
\001\001\377\201\001\003\377\201\004K\003\377\001/@f0000000/@10/@0/@0\377
\001geometry\377\001\377\201\201\013\275x\377\201\001\005\377\201\002\002
\200\327\023\270\276\305\336\377\201\002\003 \331\024\271\273\302\336\377
\201\002\004\377\201\001\314\025\271\271\305\337\377\201\002\004\200\311
\014\271\275\303\346\377\201\002\005\377\201\001\315\031\271\266\300\334
\377\001
ram-size=0x20000000
boot-args=
aapl,tdm-units=
$ 

$ dmesg
ersion 1.0
ohci2 at pci1 dev 27 function 1 "NEC USB" rev 0x43: irq 63, version 1.0
ehci0 at pci1 dev 27 function 2 "NEC USB" rev 0x04: irq 63
usb0 at ehci0: USB revision 2.0
uhub0 at usb0 "NEC EHCI root hub" rev 2.00/1.00 addr 1
usb1 at ohci0: USB revision 1.0
uhub1 at usb1 "Apple OHCI root hub" rev 1.00/1.00 addr 1
usb2 at ohci1: USB revision 1.0
uhub2 at usb2 "NEC OHCI root hub" rev 1.00/1.00 addr 1
usb3 at ohci2: USB revision 1.0
uhub3 at usb3 "NEC OHCI root hub" rev 1.00/1.00 addr 1
mpcpcibr2 at mainbus0 pci: uni-north
pci2 at mpcpcibr2 bus 0
kauaiata0 at pci2 dev 13 function 0 "Apple Intrepid ATA" rev 0x00
wdc1 at kauaiata0 irq 39: DMA
wd0 at wdc1 channel 0 drive 0: <Maxtor 2F040L0>
wd0: 16-sector PIO, LBA48, 39205MB, 80293248 sectors
wd0(wdc1:0:0): using PIO mode 4, DMA mode 2, Ultra-DMA mode 5
"Apple UniNorth Firewire" rev 0x81 at pci2 dev 14 function 0 not 
configured
gem0 at pci2 dev 15 function 0 "Apple Uni-N2 GMAC" rev 0x80: irq 41, 
address 00:0a:95:bf:c4:70
bmtphy0 at gem0 phy 0: BCM5221 100baseTX PHY, rev. 4
uhub4 at uhub2 port 1 "Mitsumi Electric Hub in Apple Extended USB 
Keyboard" rev 1.10/3.95 addr 2
uhidev0 at uhub4 port 3 configuration 1 interface 0 "Mitsumi Electric 
Apple Extended USB Keyboard" rev 1.10/3.95 addr 3
uhidev0: iclass 3/1
ukbd0 at uhidev0: 8 variable keys, 6 key codes
wskbd0 at ukbd0: console keyboard
uhidev1 at uhub4 port 3 configuration 1 interface 1 "Mitsumi Electric 
Apple Extended USB Keyboard" rev 1.10/3.95 addr 3
uhidev1: iclass 3/0, 3 report ids
uhid0 at uhidev1 reportid 2: input=1, output=0, feature=0
uhid1 at uhidev1 reportid 3: input=3, output=0, feature=0
vscsi0 at root
scsibus2 at vscsi0: 256 targets
softraid0 at root
scsibus3 at softraid0: 256 targets
bootpath: /pci@f4000000/ata-6@d/disk@0:/bsd
root on wd0a (8251ec938851c653.a) swap on wd0b dump on wd0b
drm: initializing kernel modesetting (RV280 0x1002:0x5962 0x1002:0x5962).
error: [drm:pid0:radeon_get_bios] *ERROR* Unable to locate a BIOS ROM
drm: Using device-tree clock info
radeondrm0: VRAM: 128M 0x0000000098000000 - 0x000000009FFFFFFF (32M used)
trying to bind memory to uninitialized GART !
error: [drm:pid0:radeon_ttm_backend_bind] *ERROR* failed to bind 1 pages 
at 0x00000000
error: [drm:pid0:radeon_wb_init] *ERROR* (-22) create WB bo failed
error: [drm:pid0:r100_init] *ERROR* Disabling GPU acceleration
drm: radeon: cp finalized
drm: radeon: cp finalized
Finalizing pool allocator
ttm_pool_mm_shrink_fini stub
drm: Zone  kernel: Used memory at exit: 0 kiB
drm: radeon: ttm finalized
drm: Forcing AGP to PCI mode
error: [drm:pid0:radeon_get_bios] *ERROR* Unable to locate a BIOS ROM
drm: Using device-tree clock info
radeondrm0: VRAM: 128M 0x0000000098000000 - 0x000000009FFFFFFF (32M used)
radeondrm0: GTT: 512M 0x0000000078000000 - 0x0000000097FFFFFF
drm: PCI GART of 512M enabled (table at 0x0000000001C81000).
drm: Connector Table: 1 (generic)
drm: No TMDS info found in BIOS
drm: No TV DAC info found in BIOS
radeondrm0: 1024x768
wsdisplay0 at radeondrm0 mux 1: console (std, vt100 emulation), using 
wskbd0
wsdisplay0: screen 1-5 added (std, vt100 emulation)
uhidev2 at uhub2 port 2 configuration 1 interface 0 "Mosart Wireless 
Mouse" rev 1.10/1.00 addr 4
uhidev2: iclass 3/1, 225 report ids
uhid2 at uhidev2 reportid 17: input=6, output=0, feature=0
uhid3 at uhidev2 reportid 224: input=0, output=0, feature=4
uhid4 at uhidev2 reportid 225: input=0, output=0, feature=15
syncing disks... 
[ using 561072 bytes of bsd ELF symbol table ]
console out [ATY,Merlin_A]console in [keyboard] , using USB
using parent ATY,MerlinParent:: memaddr 98000000 size 8000000, : consaddr 
9c008000, : ioaddr 90020000, size 20000: width 1024 linebytes 1024 height 
768 depth 8
Copyright (c) 1982, 1986, 1989, 1991, 1993
        The Regents of the University of California.  All rights reserved.
Copyright (c) 1995-2014 OpenBSD. All rights reserved.  http://
www.OpenBSD.org

OpenBSD 5.5-current (GENERIC) #1: Thu Jul  3 21:50:07 CDT 2014
    r...@emac.rsiegler.net:/usr/src/sys/arch/macppc/compile/GENERIC
real mem = 536870912 (512MB)
avail mem = 507064320 (483MB)
mpath0 at root
scsibus0 at mpath0: 256 targets
mainbus0 at root: model PowerMac6,4
cpu0 at mainbus0: 7457 (Revision 0x101): 1249 MHz: 512KB L2 cache
mem0 at mainbus0
spdmem0 at mem0: 512MB DDR SDRAM non-parity PC2700CL2.5
memc0 at mainbus0: uni-n rev 0xd2
"hw-clock" at memc0 not configured
kiic0 at memc0 offset 0xf8001000
iic0 at kiic0
mpcpcibr0 at mainbus0 pci: uni-north
pci0 at mpcpcibr0 bus 0
pchb0 at pci0 dev 11 function 0 "Apple UniNorth AGP" rev 0x00
radeondrm0 at pci0 dev 16 function 0 "ATI Radeon 9200" rev 0x01
drm0 at radeondrm0
radeondrm0: irq 48
mpcpcibr1 at mainbus0 pci: uni-north
pci1 at mpcpcibr1 bus 0
macobio0 at pci1 dev 23 function 0 "Apple Intrepid" rev 0x00
openpic0 at macobio0 offset 0x40000: version 0x4614 feature 3f0302 LE
macgpio0 at macobio0 offset 0x50
"modem-reset" at macgpio0 offset 0x1d not configured
"modem-power" at macgpio0 offset 0x1c not configured
macgpio1 at macgpio0 offset 0x9: irq 47
"programmer-switch" at macgpio0 offset 0x11 not configured
"fan" at macgpio0 offset 0x0 not configured
"gpio0" at macgpio0 offset 0x6a not configured
"gpio5" at macgpio0 offset 0x6f not configured
"gpio6" at macgpio0 offset 0x70 not configured
"extint-gpio4" at macgpio0 offset 0x5c not configured
"gpio11" at macgpio0 offset 0x75 not configured
"extint-gpio15" at macgpio0 offset 0x67 not configured
"escc-legacy" at macobio0 offset 0x12000 not configured
zsc0 at macobio0 offset 0x13000: irq 22,23
zstty0 at zsc0 channel 0
zstty1 at zsc0 channel 1
snapper0 at macobio0 offset 0x10000: irq 30,1,2
"timer" at macobio0 offset 0x15000 not configured
adb0 at macobio0 offset 0x16000
apm0 at adb0: battery flags 0x9, 0% charged
piic0 at adb0
iic1 at piic0
"ivad-2" at iic1 addr 0x146 not configured
"ivad-eeprom" at iic1 addr 0x153 not configured
"ivad-pwm" at iic1 addr 0x14c not configured
kiic1 at macobio0 offset 0x18000
iic2 at kiic1
wdc0 at macobio0 offset 0x20000 irq 24: DMA
atapiscsi0 at wdc0 channel 0 drive 0
scsibus1 at atapiscsi0: 2 targets
cd0 at scsibus1 targ 0 lun 0: <SONY, CD-RW CRX315E, NAK4> ATAPI 5/cdrom 
removable
cd0(wdc0:0:0): using BIOS timings, DMA mode 2
audio0 at snapper0
ohci0 at pci1 dev 26 function 0 "Apple Intrepid USB" rev 0x00: irq 29, 
version 1.0, legacy support
ohci1 at pci1 dev 27 function 0 "NEC USB" rev 0x43: irq 63, version 1.0
ohci2 at pci1 dev 27 function 1 "NEC USB" rev 0x43: irq 63, version 1.0
ehci0 at pci1 dev 27 function 2 "NEC USB" rev 0x04: irq 63
usb0 at ehci0: USB revision 2.0
uhub0 at usb0 "NEC EHCI root hub" rev 2.00/1.00 addr 1
usb1 at ohci0: USB revision 1.0
uhub1 at usb1 "Apple OHCI root hub" rev 1.00/1.00 addr 1
usb2 at ohci1: USB revision 1.0
uhub2 at usb2 "NEC OHCI root hub" rev 1.00/1.00 addr 1
usb3 at ohci2: USB revision 1.0
uhub3 at usb3 "NEC OHCI root hub" rev 1.00/1.00 addr 1
mpcpcibr2 at mainbus0 pci: uni-north
pci2 at mpcpcibr2 bus 0
kauaiata0 at pci2 dev 13 function 0 "Apple Intrepid ATA" rev 0x00
wdc1 at kauaiata0 irq 39: DMA
wd0 at wdc1 channel 0 drive 0: <Maxtor 2F040L0>
wd0: 16-sector PIO, LBA48, 39205MB, 80293248 sectors
wd0(wdc1:0:0): using PIO mode 4, DMA mode 2, Ultra-DMA mode 5
"Apple UniNorth Firewire" rev 0x81 at pci2 dev 14 function 0 not 
configured
gem0 at pci2 dev 15 function 0 "Apple Uni-N2 GMAC" rev 0x80: irq 41, 
address 00:0a:95:bf:c4:70
bmtphy0 at gem0 phy 0: BCM5221 100baseTX PHY, rev. 4
uhub4 at uhub2 port 1 "Mitsumi Electric Hub in Apple Extended USB 
Keyboard" rev 1.10/3.95 addr 2
uhidev0 at uhub4 port 3 configuration 1 interface 0 "Mitsumi Electric 
Apple Extended USB Keyboard" rev 1.10/3.95 addr 3
uhidev0: iclass 3/1
ukbd0 at uhidev0: 8 variable keys, 6 key codes
wskbd0 at ukbd0: console keyboard
uhidev1 at uhub4 port 3 configuration 1 interface 1 "Mitsumi Electric 
Apple Extended USB Keyboard" rev 1.10/3.95 addr 3
uhidev1: iclass 3/0, 3 report ids
uhid0 at uhidev1 reportid 2: input=1, output=0, feature=0
uhid1 at uhidev1 reportid 3: input=3, output=0, feature=0
uhidev2 at uhub2 port 2 configuration 1 interface 0 "Mosart Wireless 
Mouse" rev 1.10/1.00 addr 4
uhidev2: iclass 3/1, 225 report ids
uhid2 at uhidev2 reportid 17: input=6, output=0, feature=0
uhid3 at uhidev2 reportid 224: input=0, output=0, feature=4
uhid4 at uhidev2 reportid 225: input=0, output=0, feature=15
vscsi0 at root
scsibus2 at vscsi0: 256 targets
softraid0 at root
scsibus3 at softraid0: 256 targets
bootpath: /pci@f4000000/ata-6@d/disk@0:/bsd
root on wd0a (8251ec938851c653.a) swap on wd0b dump on wd0b
drm: initializing kernel modesetting (RV280 0x1002:0x5962 0x1002:0x5962).
error: [drm:pid0:radeon_get_bios] *ERROR* Unable to locate a BIOS ROM
drm: Using device-tree clock info
radeondrm0: VRAM: 128M 0x0000000098000000 - 0x000000009FFFFFFF (32M used)
trying to bind memory to uninitialized GART !
error: [drm:pid0:radeon_ttm_backend_bind] *ERROR* failed to bind 1 pages 
at 0x00000000
error: [drm:pid0:radeon_wb_init] *ERROR* (-22) create WB bo failed
error: [drm:pid0:r100_init] *ERROR* Disabling GPU acceleration
drm: radeon: cp finalized
drm: radeon: cp finalized
Finalizing pool allocator
ttm_pool_mm_shrink_fini stub
drm: Zone  kernel: Used memory at exit: 0 kiB
drm: radeon: ttm finalized
drm: Forcing AGP to PCI mode
error: [drm:pid0:radeon_get_bios] *ERROR* Unable to locate a BIOS ROM
drm: Using device-tree clock info
radeondrm0: VRAM: 128M 0x0000000098000000 - 0x000000009FFFFFFF (32M used)
radeondrm0: GTT: 512M 0x0000000078000000 - 0x0000000097FFFFFF
drm: PCI GART of 512M enabled (table at 0x0000000001C81000).
drm: Connector Table: 7 (mini internal tmds)
drm: No TMDS info found in BIOS
drm: No TV DAC info found in BIOS
No connectors reported connected with modes
Cannot find any crtc or sizes - going 1024x768
radeondrm0: 1024x768
wsdisplay0 at radeondrm0 mux 1: console (std, vt100 emulation), using 
wskbd0
wsdisplay0: screen 1-5 added (std, vt100 emulation)
syncing disks... 
[ using 561072 bytes of bsd ELF symbol table ]
console out [ATY,Merlin_A]console in [keyboard] , using USB
using parent ATY,MerlinParent:: memaddr 98000000 size 8000000, : consaddr 
9c008000, : ioaddr 90020000, size 20000: width 1024 linebytes 1024 height 
768 depth 8
Copyright (c) 1982, 1986, 1989, 1991, 1993
        The Regents of the University of California.  All rights reserved.
Copyright (c) 1995-2014 OpenBSD. All rights reserved.  http://
www.OpenBSD.org

OpenBSD 5.5-current (GENERIC) #1: Thu Jul  3 21:50:07 CDT 2014
    r...@emac.rsiegler.net:/usr/src/sys/arch/macppc/compile/GENERIC
real mem = 536870912 (512MB)
avail mem = 507064320 (483MB)
mpath0 at root
scsibus0 at mpath0: 256 targets
mainbus0 at root: model PowerMac6,4
cpu0 at mainbus0: 7457 (Revision 0x101): 1249 MHz: 512KB L2 cache
mem0 at mainbus0
spdmem0 at mem0: 512MB DDR SDRAM non-parity PC2700CL2.5
memc0 at mainbus0: uni-n rev 0xd2
"hw-clock" at memc0 not configured
kiic0 at memc0 offset 0xf8001000
iic0 at kiic0
mpcpcibr0 at mainbus0 pci: uni-north
pci0 at mpcpcibr0 bus 0
pchb0 at pci0 dev 11 function 0 "Apple UniNorth AGP" rev 0x00
radeondrm0 at pci0 dev 16 function 0 "ATI Radeon 9200" rev 0x01
drm0 at radeondrm0
radeondrm0: irq 48
mpcpcibr1 at mainbus0 pci: uni-north
pci1 at mpcpcibr1 bus 0
macobio0 at pci1 dev 23 function 0 "Apple Intrepid" rev 0x00
openpic0 at macobio0 offset 0x40000: version 0x4614 feature 3f0302 LE
macgpio0 at macobio0 offset 0x50
"modem-reset" at macgpio0 offset 0x1d not configured
"modem-power" at macgpio0 offset 0x1c not configured
macgpio1 at macgpio0 offset 0x9: irq 47
"programmer-switch" at macgpio0 offset 0x11 not configured
"fan" at macgpio0 offset 0x0 not configured
"gpio0" at macgpio0 offset 0x6a not configured
"gpio5" at macgpio0 offset 0x6f not configured
"gpio6" at macgpio0 offset 0x70 not configured
"extint-gpio4" at macgpio0 offset 0x5c not configured
"gpio11" at macgpio0 offset 0x75 not configured
"extint-gpio15" at macgpio0 offset 0x67 not configured
"escc-legacy" at macobio0 offset 0x12000 not configured
zsc0 at macobio0 offset 0x13000: irq 22,23
zstty0 at zsc0 channel 0
zstty1 at zsc0 channel 1
snapper0 at macobio0 offset 0x10000: irq 30,1,2
"timer" at macobio0 offset 0x15000 not configured
adb0 at macobio0 offset 0x16000
apm0 at adb0: battery flags 0x9, 0% charged
piic0 at adb0
iic1 at piic0
"ivad-2" at iic1 addr 0x146 not configured
"ivad-eeprom" at iic1 addr 0x153 not configured
"ivad-pwm" at iic1 addr 0x14c not configured
kiic1 at macobio0 offset 0x18000
iic2 at kiic1
wdc0 at macobio0 offset 0x20000 irq 24: DMA
atapiscsi0 at wdc0 channel 0 drive 0
scsibus1 at atapiscsi0: 2 targets
cd0 at scsibus1 targ 0 lun 0: <SONY, CD-RW CRX315E, NAK4> ATAPI 5/cdrom 
removable
cd0(wdc0:0:0): using BIOS timings, DMA mode 2
audio0 at snapper0
ohci0 at pci1 dev 26 function 0 "Apple Intrepid USB" rev 0x00: irq 29, 
version 1.0, legacy support
ohci1 at pci1 dev 27 function 0 "NEC USB" rev 0x43: irq 63, version 1.0
ohci2 at pci1 dev 27 function 1 "NEC USB" rev 0x43: irq 63, version 1.0
ehci0 at pci1 dev 27 function 2 "NEC USB" rev 0x04: irq 63
usb0 at ehci0: USB revision 2.0
uhub0 at usb0 "NEC EHCI root hub" rev 2.00/1.00 addr 1
usb1 at ohci0: USB revision 1.0
uhub1 at usb1 "Apple OHCI root hub" rev 1.00/1.00 addr 1
usb2 at ohci1: USB revision 1.0
uhub2 at usb2 "NEC OHCI root hub" rev 1.00/1.00 addr 1
usb3 at ohci2: USB revision 1.0
uhub3 at usb3 "NEC OHCI root hub" rev 1.00/1.00 addr 1
mpcpcibr2 at mainbus0 pci: uni-north
pci2 at mpcpcibr2 bus 0
kauaiata0 at pci2 dev 13 function 0 "Apple Intrepid ATA" rev 0x00
wdc1 at kauaiata0 irq 39: DMA
wd0 at wdc1 channel 0 drive 0: <Maxtor 2F040L0>
wd0: 16-sector PIO, LBA48, 39205MB, 80293248 sectors
wd0(wdc1:0:0): using PIO mode 4, DMA mode 2, Ultra-DMA mode 5
"Apple UniNorth Firewire" rev 0x81 at pci2 dev 14 function 0 not 
configured
gem0 at pci2 dev 15 function 0 "Apple Uni-N2 GMAC" rev 0x80: irq 41, 
address 00:0a:95:bf:c4:70
bmtphy0 at gem0 phy 0: BCM5221 100baseTX PHY, rev. 4
uhub4 at uhub2 port 1 "Mitsumi Electric Hub in Apple Extended USB 
Keyboard" rev 1.10/3.95 addr 2
uhidev0 at uhub4 port 3 configuration 1 interface 0 "Mitsumi Electric 
Apple Extended USB Keyboard" rev 1.10/3.95 addr 3
uhidev0: iclass 3/1
ukbd0 at uhidev0: 8 variable keys, 6 key codes
wskbd0 at ukbd0: console keyboard
uhidev1 at uhub4 port 3 configuration 1 interface 1 "Mitsumi Electric 
Apple Extended USB Keyboard" rev 1.10/3.95 addr 3
uhidev1: iclass 3/0, 3 report ids
uhid0 at uhidev1 reportid 2: input=1, output=0, feature=0
uhid1 at uhidev1 reportid 3: input=3, output=0, feature=0
uhidev2 at uhub2 port 2 configuration 1 interface 0 "Mosart Wireless 
Mouse" rev 1.10/1.00 addr 4
uhidev2: iclass 3/1, 225 report ids
uhid2 at uhidev2 reportid 17: input=6, output=0, feature=0
uhid3 at uhidev2 reportid 224: input=0, output=0, feature=4
uhid4 at uhidev2 reportid 225: input=0, output=0, feature=15
vscsi0 at root
scsibus2 at vscsi0: 256 targets
softraid0 at root
scsibus3 at softraid0: 256 targets
bootpath: /pci@f4000000/ata-6@d/disk@0:/bsd
root on wd0a (8251ec938851c653.a) swap on wd0b dump on wd0b
drm: initializing kernel modesetting (RV280 0x1002:0x5962 0x1002:0x5962).
error: [drm:pid0:radeon_get_bios] *ERROR* Unable to locate a BIOS ROM
drm: Using device-tree clock info
radeondrm0: VRAM: 128M 0x0000000098000000 - 0x000000009FFFFFFF (32M used)
trying to bind memory to uninitialized GART !
error: [drm:pid0:radeon_ttm_backend_bind] *ERROR* failed to bind 1 pages 
at 0x00000000
error: [drm:pid0:radeon_wb_init] *ERROR* (-22) create WB bo failed
error: [drm:pid0:r100_init] *ERROR* Disabling GPU acceleration
drm: radeon: cp finalized
drm: radeon: cp finalized
Finalizing pool allocator
ttm_pool_mm_shrink_fini stub
drm: Zone  kernel: Used memory at exit: 0 kiB
drm: radeon: ttm finalized
drm: Forcing AGP to PCI mode
error: [drm:pid0:radeon_get_bios] *ERROR* Unable to locate a BIOS ROM
drm: Using device-tree clock info
radeondrm0: VRAM: 128M 0x0000000098000000 - 0x000000009FFFFFFF (32M used)
radeondrm0: GTT: 512M 0x0000000078000000 - 0x0000000097FFFFFF
drm: PCI GART of 512M enabled (table at 0x0000000001C81000).
drm: Connector Table: 7 (mini internal tmds)
drm: No TMDS info found in BIOS
drm: No TV DAC info found in BIOS
No connectors reported connected with modes
Cannot find any crtc or sizes - going 1024x768
radeondrm0: 1024x768
wsdisplay0 at radeondrm0 mux 1: console (std, vt100 emulation), using 
wskbd0
wsdisplay0: screen 1-5 added (std, vt100 emulation)
$ 

Reply via email to